@@ -1,25 +1,26 @@
 
 #define PACKAGE_NAME "am-utils"
 #define PACKAGE_TARNAME "am-utils"
-#define PACKAGE_VERSION "6.1b2-pre"
-#define PACKAGE_STRING "am-utils 6.1b2-pre"
-#define PACKAGE_BUGREPORT "amd-dev@am-utils.org"
+#define PACKAGE_VERSION "6.1.1-rc1"
+#define PACKAGE_STRING "am-utils 6.1.1-rc1"
+#define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define HOST_CPU "powerpc"
 #define HOST_VENDOR "ibm"
-#define HOST_OS "aix5.1.0.0"
+#define HOST_OS "aix5.2.0.0"
 #define HOST_OS_NAME "aix5"
-#define HOST_OS_VERSION "5.1.0.0"
-#define HOST_ARCH "0052A3BA4C00"
-#define HOST_NAME "p630"
+#define HOST_OS_VERSION "5.2.0.0"
+#define HOST_ARCH "00CBE20D4C00"
+#define DISTRO_NAME "none"
+#define HOST_NAME "a-aix52p.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Tue Jan 21 02:24:45 NFT 2003"
+#define CONFIG_DATE "Fri Jul 15 10:29:33 EDT 2005"
 #define PACKAGE_NAME "am-utils"
-#define PACKAGE_VERSION "6.1b2-pre"
-#define PACKAGE_BUGREPORT "amd-dev@am-utils.org"
+#define PACKAGE_VERSION "6.1.1-rc1"
+#define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define PACKAGE "am-utils"
-#define VERSION "6.1b2-pre"
-#define DEBUG 1
+#define VERSION "6.1.1-rc1"
 #define _ALL_SOURCE 1
+#define DEBUG 1
 #define STDC_HEADERS 1
 #define HAVE_SYS_TYPES_H 1
 #define HAVE_SYS_STAT_H 1
@@ -28,16 +29,17 @@
 #define HAVE_MEMORY_H 1
 #define HAVE_STRINGS_H 1
 #define HAVE_INTTYPES_H 1
+#define HAVE_STDINT_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_DLFCN_H 1
 #ifdef __cplusplus
-void exit (int);
+#include <stdlib.h>
 #endif
-#define HOST_HEADER_VERSION "5.1.0.0"
+#define HOST_HEADER_VERSION "5.2.0.0"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
-#define HAVE_ALLOCA_H 1
-#define HAVE_ALLOCA 1
+#define HAVE_LIBLDAP 1
+#define HAVE_LIBRT 1
 #define HAVE_UNISTD_H 1
 #define HAVE_FORK 1
 #define HAVE_VFORK 1
@@ -51,6 +53,7 @@ void exit (int);
 #define HAVE_BCOPY 1
 #define HAVE_BZERO 1
 #define HAVE_CLNT_CREATE 1
+#define HAVE_CLNT_CREATE_VERS 1
 #define HAVE_CLNT_SPCREATEERROR 1
 #define HAVE_CLOCK_GETTIME 1
 #define HAVE_GET_MYADDRESS 1
@@ -61,6 +64,8 @@ void exit (int);
 #define HAVE_GETPAGESIZE 1
 #define HAVE_GETTIMEOFDAY 1
 #define HAVE_HASMNTOPT 1
+#define HAVE_HSTRERROR 1
+#define HAVE_MADVISE 1
 #define HAVE_MEMCMP 1
 #define HAVE_MEMCPY 1
 #define HAVE_MEMMOVE 1
@@ -80,10 +85,11 @@ void exit (int);
 #define HAVE_SETSID 1
 #define HAVE_SIGACTION 1
 #define HAVE_SIGNAL 1
+#define HAVE_SIGSUSPEND 1
 #define HAVE_SOCKET 1
+#define HAVE_STRCASECMP 1
 #define HAVE_STRCHR 1
 #define HAVE_STRCSPN 1
-#define HAVE_STRCASECMP 1
 #define HAVE_STRDUP 1
 #define HAVE_STRERROR 1
 #define HAVE_STRSPN 1
@@ -169,6 +175,7 @@ void exit (int);
 #define HAVE_FCNTL_H 1
 #define HAVE_GRP_H 1
 #define HAVE_LIBGEN_H 1
+#define HAVE_LIMITS_H 1
 #define HAVE_MALLOC_H 1
 #define HAVE_MEMORY_H 1
 #define HAVE_MNTENT_H 1
@@ -189,17 +196,16 @@ void exit (int);
 #define HAVE_SYSLOG_H 1
 #define HAVE_TIME_H 1
 #define HAVE_TIUSER_H 1
-#define HAVE_VARARGS_H 1
 #define HAVE_UNISTD_H 1
 #define TIME_WITH_SYS_TIME 1
-#define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_aix5_1.h"
+#define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_aix5_2.h"
 #define HAVE_STRUCT_MNTENT 1
 #define HAVE_BAD_HASMNTOPT 1
 #define HAVE_STRUCT_NFS_ARGS 1
-#define nfs_args_t struct aix51_nfs_args
+#define nfs_args_t struct aix5_nfs_args
 #define NFS_FH_FIELD fh
 #define am_nfs_fh nfs_fh
-#define am_nfs_fh3 nfs_fh3
+#define HAVE_FS_NFS3 1
 #define GETGROUPS_T gid_t
 #define RETSIGTYPE void
 #define MTYPE_TYPE int
@@ -227,6 +233,7 @@ void exit (int);
 #define HAVE_EXTERN_SBRK 1
 #define HAVE_EXTERN_SETEUID 1
 #define HAVE_EXTERN_SETITIMER 1
+#define HAVE_EXTERN_SLEEP 1
 #define HAVE_EXTERN_STRCASECMP 1
 #define HAVE_EXTERN_STRDUP 1
 #define HAVE_EXTERN_STRSTR 1
@@ -238,27 +245,25 @@ void exit (int);
 #define HAVE_EXTERN_XDR_OPAQUE_AUTH 1
 #define HAVE_LONG_FILE_NAMES 1
 #define HAVE_UNISTD_H 1
+#define HAVE_FD_SET_FDS_BITS 1
 #define HAVE_STRUCT_FHSTATUS_FHS_FH 1
 #define HAVE_NFS_ARGS_T_ACDIRMIN 1
 #define HAVE_NFS_ARGS_T_ACREGMIN 1
 #define HAVE_NFS_ARGS_T_PROTO 1
 #define HAVE_STRUCT_IFREQ_IFR_ADDR 1
 #define HAVE_STRUCT_SOCKADDR_SA_LEN 1
-#define HAVE_STRUCT_UMNTREQUEST_DEVID 1
 #define HAVE_MAP_FILE 1
-#define HAVE_MAP_NDBM 1
+#define HAVE_MAP_EXEC 1
 #define HAVE_MAP_NIS 1
 #define HAVE_MAP_PASSWD 1
 #define HAVE_MAP_UNION 1
 #define HAVE_FS_CDFS 1
 #define HAVE_FS_NFS 1
-#define HAVE_FS_NFS3 1
 #define HAVE_FS_UFS 1
 #define HAVE_AMU_FS_AUTO 1
 #define HAVE_AMU_FS_DIRECT 1
 #define HAVE_AMU_FS_TOPLVL 1
 #define HAVE_AMU_FS_ERROR 1
-#define HAVE_AMU_FS_INHERIT 1
 #define HAVE_AMU_FS_PROGRAM 1
 #define HAVE_AMU_FS_LINK 1
 #define HAVE_AMU_FS_LINKX 1
@@ -295,6 +300,7 @@ void exit (int);
 #define MNTTAB_OPT_SOFT "soft"
 #define MNTTAB_OPT_SUID "suid"
 #define MNTTAB_OPT_TIMEO "timeo"
+#define MNTTAB_OPT_VERS "vers"
 #define MNTTAB_OPT_WSIZE "wsize"
 #define MNT2_GEN_OPT_NODEV 0x80
 #define MNT2_GEN_OPT_NOSUID 0x40
@@ -302,12 +308,13 @@ void exit (int);
 #define MNT2_NFS_OPT_ACDIRMIN 0x400
 #define MNT2_NFS_OPT_ACREGMAX 0x200
 #define MNT2_NFS_OPT_ACREGMIN 0x100
-#define MNT2_NFS_OPT_GRPID 0x40000
+#define MNT2_NFS_OPT_GRPID 0x8000
 #define MNT2_NFS_OPT_HOSTNAME 0x20
 #define MNT2_NFS_OPT_INT 0x40
+#define MNT2_NFS_OPT_KNCONF 0x4000
 #define MNT2_NFS_OPT_NOAC 0x80
 #define MNT2_NFS_OPT_NOCTO 0x2000
-#define MNT2_NFS_OPT_POSIX 0x4000
+#define MNT2_NFS_OPT_POSIX 0x40000
 #define MNT2_NFS_OPT_RETRANS 0x10
 #define MNT2_NFS_OPT_RSIZE 0x4
 #define MNT2_NFS_OPT_SOFT 0x1
